Contribute to NLTK
==================

The Natural Language Toolkit exists thanks to the efforts of dozens
of voluntary developers who have contributed functionality and
bugfixes since the project began in 2000 (`contributors <https://github.com/nltk/nltk/blob/develop/AUTHORS.md>`_).
Information for contributors:

* `contributing to NLTK <https://github.com/nltk/nltk/blob/develop/CONTRIBUTING.md>`_
* `desired enhancements <https://github.com/nltk/nltk/issues?labels=enhancement&page=1&state=open>`_
* `contribute a corpus <https://github.com/nltk/nltk/wiki/Adding-a-Corpus>`_
* `nltk-dev mailing list <http://groups.google.com/group/nltk-dev>`_
* `GitHub Project <https://github.com/nltk/nltk>`_

NLTK Team
---------

The NLTK project is led by `Steven Bird and Liling Tan <mailto:stevenbird1@gmail.com,alvations@gmail.com>`_.
Individual packages are maintained by the following people:

:Semantics: `Dan Garrette <http://www.cs.utexas.edu/~dhg/>`_, Austin, USA (``nltk.sem, nltk.inference``)
:Parsing: `Peter Ljunglöf <http://www.cse.chalmers.se/~peb/>`_, Gothenburg, Sweden (``nltk.parse, nltk.featstruct``)
:Metrics: `Joel Nothman <http://joelnothman.com/>`_, Sydney, Australia (``nltk.metrics, nltk.tokenize.punkt``)
:Python 3: `Mikhail Korobov <http://kmike.ru/>`_, Ekaterinburg, Russia
:Releases: `Steven Bird <http://estive.net>`_, Melbourne, Australia
:NLTK-Users: `Alexis Dimitriadis <A.Dimitriadis@uu.nl>`_, Utrecht, Netherlands
